@@ -195,7 +195,7 @@ import sys
 from mako.lookup import TemplateLookup
 from mako.exceptions import TopLevelLookupException
 
-__version__ = '0.0.19'
+__version__ = '0.1.0'
 """
 The current version of pdoc. This value is read from `setup.py`.
 """
@@ -404,7 +404,8 @@ def _var_docstrings(tree, module, cls=None, init=False):
                 name = child.targets[0].attr
             else:
                 continue
-            if not _is_exported(name):
+            if not _is_exported(name) \
+                    and name not in getattr(module, '__all__', []):
                 continue
 
             docstring = ''
@@ -572,6 +573,9 @@ class Module (Doc):
                     self.doc[name] = self.__new_submodule(name, obj)
             elif name in vardocs:
                 self.doc[name] = vardocs[name]
+            else:
+                # Catch all for variables.
+                self.doc[name] = Variable(name, self, '', cls=None)
 
         # Now scan the directory if this is a package for all modules.
         if not hasattr(self.module, '__path__') \
